@@ -53,6 +53,8 @@ typedef enum {
 struct remote_dev_info {
 	bdaddr_t bdaddr;
 	int8_t rssi;
+	uint32_t class;
+	char *alias;
 	name_status_t name_status;
 };
 
@@ -88,7 +90,7 @@ struct hci_dev {
 	uint8_t  lmp_ver;
 	uint16_t lmp_subver;
 	uint16_t hci_rev;
-	uint16_t err;
+	uint16_t manufacturer;
 
 	uint8_t  ssp_mode;
 	uint8_t  name[248];
@@ -127,24 +129,19 @@ void adapter_remove_auth_request(struct btd_adapter *adapter, bdaddr_t *dba);
 struct pending_auth_info *adapter_new_auth_request(struct btd_adapter *adapter,
 							bdaddr_t *dba,
 							auth_type_t type);
-struct btd_adapter *adapter_create(DBusConnection *conn, int id);
+struct btd_adapter *adapter_create(DBusConnection *conn, int id,
+				gboolean devup);
 void adapter_remove(struct btd_adapter *adapter);
 uint16_t adapter_get_dev_id(struct btd_adapter *adapter);
 const gchar *adapter_get_path(struct btd_adapter *adapter);
 void adapter_get_address(struct btd_adapter *adapter, bdaddr_t *bdaddr);
-void adapter_remove(struct btd_adapter *adapter);
-void adapter_set_discov_timeout(struct btd_adapter *adapter, guint interval);
-void adapter_remove_discov_timeout(struct btd_adapter *adapter);
-void adapter_set_scan_mode(struct btd_adapter *adapter, uint8_t scan_mode);
-uint8_t adapter_get_scan_mode(struct btd_adapter *adapter);
-void adapter_set_mode(struct btd_adapter *adapter, uint8_t mode);
-uint8_t adapter_get_mode(struct btd_adapter *adapter);
 void adapter_set_state(struct btd_adapter *adapter, int state);
 int adapter_get_state(struct btd_adapter *adapter);
 struct remote_dev_info *adapter_search_found_devices(struct btd_adapter *adapter,
 						struct remote_dev_info *match);
 int adapter_add_found_device(struct btd_adapter *adapter, bdaddr_t *bdaddr,
-				int8_t rssi, name_status_t name_status);
+				int8_t rssi, uint32_t class, const char *alias,
+				name_status_t name_status);
 int adapter_remove_found_device(struct btd_adapter *adapter, bdaddr_t *bdaddr);
 void adapter_update_oor_devices(struct btd_adapter *adapter);
 void adapter_remove_oor_device(struct btd_adapter *adapter, char *peer_addr);
@@ -154,9 +151,8 @@ void adapter_add_active_conn(struct btd_adapter *adapter, bdaddr_t *bdaddr,
 				uint16_t handle);
 void adapter_remove_active_conn(struct btd_adapter *adapter,
 				struct active_conn_info *dev);
-void adapter_update_devices(struct btd_adapter *adapter);
 struct active_conn_info *adapter_search_active_conn_by_bdaddr(struct btd_adapter *adapter,
-						    bdaddr_t *bda);
+								bdaddr_t *bda);
 struct active_conn_info *adapter_search_active_conn_by_handle(struct btd_adapter *adapter,
 							uint16_t handle);
 void adapter_free_bonding_request(struct btd_adapter *adapter);
@@ -176,3 +172,10 @@ void btd_unregister_adapter_driver(struct btd_adapter_driver *driver);
 int btd_request_authorization(const bdaddr_t *src, const bdaddr_t *dst,
 		const char *uuid, service_auth_cb cb, void *user_data);
 int btd_cancel_authorization(const bdaddr_t *src, const bdaddr_t *dst);
+
+const char *adapter_any_get_path(void);
+
+const char *btd_adapter_any_request_path(void);
+void btd_adapter_any_release_path(void);
+gboolean adapter_is_pairable(struct btd_adapter *adapter);
+gboolean adapter_pairing_initiator(struct btd_adapter *adapter, bdaddr_t *bda);
